package ai.pai.lensman.printer;

import android.os.Bundle;
import android.support.annotation.Nullable;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;
import android.widget.ToggleButton;

import com.android.views.mergeAdapter.MergeAdapter;

import ai.pai.lensman.R;
import ai.pai.lensman.base.BaseActivity;
import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;

/**
 * Created by chengzhenyu on 2016/8/31.
 */

public class PrinterSettingActivity extends BaseActivity implements PrinterSettingContract.View {

    @BindView(R.id.tv_printer_status)  TextView printerStatusText;
    @BindView(R.id.tv_bluetooth_status) TextView bluetoothStatusText;
    @BindView(R.id.tb_bluetooth_switch)   ToggleButton btSwitchToggle;
    @BindView(R.id.list_bt_devices)    ListView btDevicesList;

    private MergeAdapter mergeAdapter;
    private BluetoothDeviceListAdapter newDeviceAdapter;
    private BluetoothDeviceListAdapter pairedDeviceAdapter;
    private PrinterSettingContract.Presenter presenter;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_printer_setting);
        unbinder = ButterKnife.bind(this);

        mergeAdapter = new MergeAdapter();
        newDeviceAdapter = new BluetoothDeviceListAdapter(this);
        pairedDeviceAdapter = new BluetoothDeviceListAdapter(this);

        btDevicesList.setAdapter(mergeAdapter);
        mergeAdapter.addAdapter(pairedDeviceAdapter);
        mergeAdapter.addAdapter(newDeviceAdapter);
        presenter = new PrinterSettingPresenter(this,this);
        presenter.start();
    }

    @Override
    protected void onDestroy() {
        presenter.stop();
        super.onDestroy();
    }

    @Override
    public void onBluetoothEnabled() {
        bluetoothStatusText.setText(R.string.bt_is_enabled);
    }

    @Override
    public void onBluetoothDisabled() {
        bluetoothStatusText.setText(R.string.bt_is_disabled);
    }

    @Override
    public void onPrinterOk() {
        printerStatusText.setText(R.string.printer_is_ok);
    }

    @Override
    public void onPrinterError(String error) {
        printerStatusText.setText(error);
    }

    @Override
    public void onPrinterConnected() {
        Toast.makeText(this,R.string.printer_is_connected,Toast.LENGTH_SHORT).show();
    }

    @Override
    public void onPrinterDisconnected() {
        Toast.makeText(this,R.string.printer_is_disconnected,Toast.LENGTH_SHORT).show();
    }

    @Override
    public void onNewDeviceDiscovered() {

    }

    @Override
    public void onPrinterTestPageFail() {

    }

    @Override
    public void onPairedDeviceDiscovered() {

    }

    @OnClick(R.id.tv_print_test)
    void testPrint(){
        presenter.printTestPage();
    }
}
